@@ -1,24 +1,22 @@
-/***************************************************************************
-			disc.h
-
- *   Copyright (C) 2006 by Christophe Thommeret                                   *
- *   hftom@free.fr                                                         *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Steet, Fifth Floor, Boston, MA 02110-1301, USA.           *
- ***************************************************************************/
+/*
+ * disc.h
+ *
+ * Copyright (C) 2006 Christophe Thommeret <hftom@free.fr>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
+ */
 
 #ifndef DISC_H
 #define DISC_H
@@ -42,8 +40,6 @@
 
 class MRL;
 
-
-
 class MLabel : public QLabel
 {
 	Q_OBJECT
@@ -93,6 +89,7 @@ public:
 	void toggleLayout( bool );
 	void playerStopped();
 	void getTargets( QStringList &uiNames, QStringList &iconNames, QStringList &targetNames );
+	void togglePanel();
 	bool execTarget( const QString& );
 	void saveConfig();
 	//***************************************
@@ -139,4 +136,5 @@ signals:
 	void signalRequestForDVD();
 	void signalRequestForVCD();
 };
-#endif
+
+#endif /* DISC_H */
