@@ -1,7 +1,7 @@
 /*
  * dvbconfig.h
  *
- * Copyright (C) 2004-2005 Christophe Thommeret <hftom@free.fr>
+ * Copyright (C) 2004-2007 Christophe Thommeret <hftom@free.fr>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -154,8 +154,8 @@ public:
 	void changeIconCategory( const QString &name, const QString &icon );
 
 	KConfig *config;
-	QString recordDir, shiftDir;
-	int beginMargin, endMargin, format, instantDuration;
+	QString recordDir, shiftDir, filenameFormat;
+	int beginMargin, endMargin, instantDuration, sizeFile;
 	QSize epgSize, scanSize, timerSize;
 	QPtrList<Device> devList;
 	QPtrList<Category> categories;
@@ -194,8 +194,8 @@ public:
 	~DvbConfigDialog();
 	void setSource( QComboBox *box, QString s );
 
-	QLineEdit *recordDirLe, *shiftDirLe, *broadcastLe;
-	QSpinBox *beginSpin, *endSpin, *instantDurationSpin, *bportSpin, *sportSpin;
+	QLineEdit *recordDirLe, *shiftDirLe, *broadcastLe, *filenameFormatLe;
+	QSpinBox *beginSpin, *endSpin, *instantDurationSpin, *bportSpin, *sportSpin, *sizeFileSpin;
 	MSpinBox *satNumber[8];
 	QComboBox *sat0[8];
 	QComboBox *sat1[8];
@@ -213,15 +213,15 @@ public:
 	MPushButton *lnb1[8];
 	MPushButton *lnb2[8];
 	MPushButton *lnb3[8];
-	QComboBox *formatComb;
 	KPushButton *updateBtn, *dumpBtn;
-	QToolButton *recordDirBtn, *shiftDirBtn;
+	QToolButton *recordDirBtn, *shiftDirBtn, *helpNameBtn;
 	DVBconfig *dvbConfig;
 	QComboBox *charsetComb;
 	QPtrList<QSpinBox> timeoutSpin;
 
 private slots:
 
+	void fileTemplateHelp();
 	void setRecordDir();
 	void setShiftDir();
 	void satNumberChanged( int value, int devNum );
