@@ -1,7 +1,7 @@
 /*
  * dvbstream.cpp
  *
- * Copyright (C) 2003-2006 Christophe Thommeret <hftom@free.fr>
+ * Copyright (C) 2003-2007 Christophe Thommeret <hftom@free.fr>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -54,7 +54,7 @@
 
 
 
-DvbStream::DvbStream( Device *d, const QString &charset )
+DvbStream::DvbStream( Device *d, const QString &charset, EventTable *et )
 {
 	dvbDevice = d;
 	isRunning = false;
@@ -70,8 +70,14 @@ DvbStream::DvbStream( Device *d, const QString &charset )
 
 	out.setAutoDelete( true );
 
-	bool bok;
-	dvbEvents = new DVBevents( &bok, dvbDevice->adapter, dvbDevice->tuner, charset );
+	QString deviceType="NONE";
+	switch ( dvbDevice->type ) {
+		case FE_QPSK: deviceType = "DVBS"; break;
+		case FE_OFDM: deviceType = "DVBT"; break;
+		case FE_QAM: deviceType = "DVBC"; break;
+		case FE_ATSC: deviceType = "DVBA"; break;
+	}
+	dvbEvents = new DVBevents( deviceType, dvbDevice->adapter, dvbDevice->tuner, charset, et );
 
 	camProbed = false;
 	cam = NULL;
@@ -281,6 +287,13 @@ Transponder DvbStream::getCurrentTransponder()
 
 
 
+unsigned long DvbStream::getCurrentFreq()
+{
+	return currentTransponder.freq;
+}
+
+
+
 bool DvbStream::isTuned()
 {
 	if ( fdFrontend )
@@ -480,6 +493,7 @@ int DvbStream::setDiseqc( int switchPos, ChannelDesc *chan, int hiband, int &rot
 		{ { 0xe0, 0x10, 0x38, 0xff, 0x00, 0x00 }, 4 },
 	};
 
+	int i;
 	int voltage18 = ( (chan->tp.pol=='H')||(chan->tp.pol=='h') );
 	int ci = 4 * switchPos + 2 * hiband + (voltage18 ? 1 : 0);
 
@@ -489,12 +503,16 @@ int DvbStream::setDiseqc( int switchPos, ChannelDesc *chan, int hiband, int &rot
 
 	if ( ioctl(fdFrontend, FE_SET_TONE, SEC_TONE_OFF) )
 		perror("FE_SET_TONE failed");
+	usleep(15*1000);
 	if ( ioctl(fdFrontend, FE_SET_VOLTAGE, ci%2 ? SEC_VOLTAGE_18 : SEC_VOLTAGE_13) )
 		perror("FE_SET_VOLTAGE failed");
-	usleep(15*1000);
+
 	fprintf( stderr, "DiSEqC: %02x %02x %02x %02x %02x %02x\n", switchCmd[ci].msg[0], switchCmd[ci].msg[1], switchCmd[ci].msg[2], switchCmd[ci].msg[3], switchCmd[ci].msg[4], switchCmd[ci].msg[5] );
-	if ( ioctl(fdFrontend, FE_DISEQC_SEND_MASTER_CMD, &switchCmd[ci]) )
-		perror("FE_DISEQC_SEND_MASTER_CMD failed");
+	for ( i=0; i<2; ++i ) {
+		usleep(15*1000);
+		if ( ioctl(fdFrontend, FE_DISEQC_SEND_MASTER_CMD, &switchCmd[ci]) )
+			perror("FE_DISEQC_SEND_MASTER_CMD failed");
+	}
 
 	QString msg;
 	if ( dvbDevice->lnb[switchPos].rotorType!=0 && chan->tp.source!=dvbDevice->lnb[switchPos].currentSource ) {
@@ -557,9 +575,12 @@ int DvbStream::setDiseqc( int switchPos, ChannelDesc *chan, int hiband, int &rot
 		}
 	}
 
-	usleep(15*1000);
-	if ( ioctl(fdFrontend, FE_DISEQC_SEND_BURST, (ci/4)%2 ? SEC_MINI_B : SEC_MINI_A) )
-		perror("FE_DISEQC_SEND_BURST failed");
+	for ( i=0; i<2; ++i ) {
+		usleep(15*1000);
+		if ( ioctl(fdFrontend, FE_DISEQC_SEND_BURST, (ci/4)%2 ? SEC_MINI_B : SEC_MINI_A) )
+			perror("FE_DISEQC_SEND_BURST failed");
+	}
+
 	usleep(15*1000);
 	if ( ioctl(fdFrontend, FE_SET_TONE, (ci/2)%2 ? SEC_TONE_ON : SEC_TONE_OFF) )
 		perror("FE_SET_TONE failed");
@@ -659,27 +680,24 @@ void DvbStream::rotorCommand( int cmd, int n1, int n2, int n3 )
 		{ { 0xe0, 0x10, 0x38, 0xF4, 0x00, 0x00 }, 4 }    //13 User
 	};
 
-	if ( ioctl( fdFrontend, FE_DISEQC_SEND_MASTER_CMD, &cmds[cmd] ) )
-		perror("Rotor : FE_DISEQC_SEND_MASTER_CMD failed");
+	int i;
+	for ( i=0; i<2; ++i ) {
+		usleep(15*1000);
+		if ( ioctl( fdFrontend, FE_DISEQC_SEND_MASTER_CMD, &cmds[cmd] ) )
+			perror("Rotor : FE_DISEQC_SEND_MASTER_CMD failed");
+	}
 }
 
 
 
-bool DvbStream::setPids( DVBout *o, int napid )
+bool DvbStream::setPids( DVBout *o )
 {
 	int i, dmx;
 	struct dmx_pes_filter_params pesFilterParams;
 	dmx_pes_type_t pestype = DMX_PES_OTHER;
 	QValueList<int> pidList;
 
-	if ( o->channel.vpid )
-		pidList.append( o->channel.vpid );
-	pidList.append( o->channel.apid[napid].pid );
-	if ( o->channel.subpid[0].pid )
-		pidList.append( o->channel.subpid[0].pid );
-
-	/*if ( (ndmx+pidList.count())>MAX_CHANNELS )
-		return false;*/
+	pidList = o->pidsList();
 
 	for ( i=0; i<(int)pidList.count(); i++ ) {
 		if ( ( dmx = open( demuxName.ascii(), O_RDWR)) < 0 ) {
@@ -1001,6 +1019,8 @@ bool DvbStream::startBroadcast( QPtrList<ChannelDesc> *list, Ts2Rtp *rtp )
 	DVBout *o=0;
 	int no=0;
 	ChannelDesc *chan=list->at(0);
+	QPtrList<ChannelDesc> broadcastList;
+	broadcastList.setAutoDelete( true );
 
 	if ( !isTuned() ) {
 		for ( i=0; i<MAXTUNETRY; i++ ) {
@@ -1031,7 +1051,7 @@ bool DvbStream::startBroadcast( QPtrList<ChannelDesc> *list, Ts2Rtp *rtp )
 			connect( o, SIGNAL(playDvb()), this, SLOT(receivePlayDvb()) );
 			connect( o, SIGNAL(shifting(bool)), this, SLOT(receiveShifting(bool)) );
 			out.append( o );
-			if ( !setPids( o, 0 ) ) {
+			if ( !setPids( o ) ) {
 				removePids( o );
 				removeOut( o );
 				o = 0;
@@ -1047,21 +1067,24 @@ bool DvbStream::startBroadcast( QPtrList<ChannelDesc> *list, Ts2Rtp *rtp )
 					removeOut( o );
 				}
 			}
-			else
+			else {
+				broadcastList.append( new ChannelDesc( *list->at(i) ) );
 				no++;
+			}
 		}
 	}
 
 	if ( !no && stop )
 		stopFrontend();
+	else
+		rtp->addChannels( &broadcastList );
 
 	fprintf(stderr,"NOUT: %d\n", out.count() );
-	fprintf(stderr,"NO: %d\n", no );
-
-	startReading();
 
 	if ( !no )
 		return false;
+	else
+		startReading();
 	emit isBroadcasting( true );
 	return true;
 }
@@ -1086,8 +1109,6 @@ int DvbStream::canStartTimer( bool &live, ChannelDesc *chan )
 		if ( o->hasLive() ) {
 			if ( chan->tp!=o->channel.tp )
 				live = true;
-			else if ( (o->channel.name==chan->name) && (o->currentAudioPid()!=0) )
-				live = true;
 			else if ( cam && chan->fta && o->channel.fta )
 				live = true;
 		}
@@ -1097,7 +1118,7 @@ int DvbStream::canStartTimer( bool &live, ChannelDesc *chan )
 
 
 
-bool DvbStream::startTimer( ChannelDesc *chan, QString path, RecTimer *t )
+bool DvbStream::startTimer( ChannelDesc *chan, QString path, int maxsize, RecTimer *t, QString name )
 {
 	int i;
 	bool stop=false, newout=false;
@@ -1146,7 +1167,7 @@ bool DvbStream::startTimer( ChannelDesc *chan, QString path, RecTimer *t )
 		connect( o, SIGNAL(playDvb()), this, SLOT(receivePlayDvb()) );
 		connect( o, SIGNAL(shifting(bool)), this, SLOT(receiveShifting(bool)) );
 		out.append( o );
-		if ( !setPids( o, 0 ) ) {
+		if ( !setPids( o ) ) {
 			if ( stop )
 				stopFrontend();
 			removePids( o );
@@ -1156,10 +1177,13 @@ bool DvbStream::startTimer( ChannelDesc *chan, QString path, RecTimer *t )
 		newout = true;
 	}
 
-	QString name = path+t->name;
-	if ( t->mode )
-		name = name+"-"+t->begin.date().toString( Qt::ISODate );
-	if ( !o->goRec( t->filetype, name, t ) ) {
+	if ( t->mode && !name.contains("%date") )
+		name+= "-%date";
+	name = name.replace( "%chan", chan->name ).replace("%date", t->begin.toString( "yyyyMMdd-hhmmss" ) ).replace("%name", t->name );
+	name = name.replace( "/", "_" ).replace( ">", "_" ).replace("<","_").replace(":","_").replace('"',"_").replace("\\","_").replace("|","_");
+	name = path+name;
+
+	if ( !o->goRec( name, maxsize, t ) ) {
 		if ( stop )
 			stopFrontend();
 		if ( newout ) {
@@ -1181,7 +1205,7 @@ bool DvbStream::startTimer( ChannelDesc *chan, QString path, RecTimer *t )
 
 
 
-int DvbStream::goLive( ChannelDesc *chan, const QString &pipeName, int &napid )
+int DvbStream::goLive( ChannelDesc *chan, const QString &pipeName )
 {
 	int i;
 	bool stop=false;
@@ -1221,7 +1245,7 @@ int DvbStream::goLive( ChannelDesc *chan, const QString &pipeName, int &napid )
 		connect( o, SIGNAL(playDvb()), this, SLOT(receivePlayDvb()) );
 		connect( o, SIGNAL(shifting(bool)), this, SLOT(receiveShifting(bool)) );
 		out.append( o );
-		if ( !setPids( o, napid ) ) {
+		if ( !setPids( o ) ) {
 			if ( stop )
 				stopFrontend();
 			removePids( o );
@@ -1230,13 +1254,12 @@ int DvbStream::goLive( ChannelDesc *chan, const QString &pipeName, int &napid )
 		}
 	}
 
-	if ( o->hasRec() ) {
-		napid = o->currentAudioPid();
+	if ( o->hasRec() )
 		i = ErrDontSwitchAudio;
-	}
-	else i = 0;
+	else
+		i = 0;
 
-	o->goLive( pipeName, napid );
+	o->goLive( pipeName );
 	fprintf(stderr,"NOUT: %d\n", out.count() );
 
 	if ( chan->fta && cam && !cam->running() )
@@ -1306,7 +1329,7 @@ void DvbStream::startReading()
 	if ( !isRunning ) {
 		isRunning = true;
 		start();
-		dvbEvents->go( currentTransponder.source, true );
+		dvbEvents->go( currentTransponder.source, currentTransponder.freq, true );
 	}
 }
 
@@ -1315,7 +1338,7 @@ void DvbStream::startReading()
 void DvbStream::stop()
 {
 	isRunning = false;
-	if ( !wait(5000) ) {
+	if ( !wait(10000) ) {
 		terminate();
 		wait();
 		fprintf(stderr,"dvbstream::run() terminated\n");
