@@ -83,6 +83,16 @@ CdWidget::CdWidget( const QString &ad, int port, int info, const QString &tspath
 
 
 
+void CdWidget::togglePanel()
+{
+	if ( channelsLb->isHidden() )
+		channelsLb->show();
+	else
+		channelsLb->hide();
+}
+
+
+
 void CdWidget::getTargets( QStringList &uiNames, QStringList &iconNames, QStringList &targetNames )
 {
 	uiNames.append( i18n("DVB Client") );
