@@ -449,6 +449,11 @@ void XinePart::slotTogglePause( bool pauseLive )
 	}
 }
 
+void XinePart::speedFaster()
+{
+	slotFastForward();
+}
+
 void XinePart::slotFastForward()
 {
 	if (m_xine->getSpeed() == KXineWidget::Pause)
@@ -459,6 +464,11 @@ void XinePart::slotFastForward()
 	m_xine->slotSpeedFaster();
 }
 
+void XinePart::speedSlower()
+{
+	slotSlowMotion();
+}
+
 void XinePart::slotSlowMotion()
 {
 	if (m_xine->getSpeed() == KXineWidget::Pause)
@@ -683,13 +693,14 @@ void XinePart::setDVDChapter(uint chapter)
 
 void XinePart::slotChannelInfo(const QStringList& audio, const QStringList& sub, int currentAudio, int currentSub)
 {
+	kdDebug() << "XinePart: slotChannelInfo: currentAudio="<<currentAudio<< "  currentSub="<<currentSub<<"\n";
 	m_audioChannels->setItems(audio);
-	m_audioChannels->setCurrentItem(currentAudio);
+	m_audioChannels->setCurrentItem(currentAudio+1);
 
 	if (m_playlist[m_current].subtitleFiles().isEmpty())
 	{
 		m_subtitles->setItems(sub);
-		m_subtitles->setCurrentItem(currentSub);
+		m_subtitles->setCurrentItem(currentSub+1);
 	}
 	else
 	{
@@ -779,6 +790,17 @@ void XinePart::slotNewPosition(int pos, const QTime& playtime)
 			m_xine->showOSDMessage(timeMessage, 600, OSD_MESSAGE_LOW_PRIORITY);
 		}
 	}
+	currentPosition = (playtime.hour()*3600)+(playtime.minute()*60)+playtime.second();
+}
+
+QString XinePart::screenShot()
+{
+	QString filename = QDir::homeDirPath()+"/kaffeinedcopshot.jpg";
+	QImage shot = m_xine->getScreenshot();
+	if ( shot.save( filename, "JPEG" ) )
+		return filename;
+	else
+		return "";
 }
 
 void XinePart::slotScreenshot()
@@ -1334,6 +1356,7 @@ void XinePart::initActions()
 	m_audioChannels->setToolTip(i18n("Select audio channel"));
 	m_audioChannels->setComboWidth( 50 );
 	connect(m_audioChannels, SIGNAL(activated(int)), this, SLOT(slotSetAudioChannel(int )));
+	new KAction(i18n("&Next Audio Channel"), 0, 0, this, SLOT(slotNextAudioChannel()), actionCollection(), "next_audio_channels");
 	m_audioVisual = new KSelectAction(i18n("Audio &Visualization"), 0, actionCollection(), "audio_visualization");
 	connect(m_audioVisual, SIGNAL(activated(const QString&)), m_xine, SLOT(slotSetVisualPlugin(const QString&)));
 	new KAction(i18n("&Mute"), "player_mute", Key_U, this, SLOT(slotMute()), actionCollection(), "audio_mute");
@@ -1363,6 +1386,7 @@ void XinePart::initActions()
 	m_subtitles->setToolTip(i18n("Select Subtitle"));
 	m_subtitles->setComboWidth( 50 );
 	connect(m_subtitles, SIGNAL(activated(int)), this, SLOT(slotSetSubtitle(int)));
+	new KAction(i18n("&Next Subtitle Channel"), 0, 0, this, SLOT(slotNextSubtitleChannel()), actionCollection(), "next_player_subtitles");
 	new KAction(i18n("Delay Subtitle"), 0, CTRL|ALT|Key_Left, this, SLOT(slotDelaySubTitle()), actionCollection(), "adv_sub");
 	new KAction(i18n("Advance Subtitle"), 0, CTRL|ALT|Key_Right, this, SLOT(slotAdvanceSubTitle()), actionCollection(), "delay_sub");
 	new KAction(i18n("Add subtitle..."), 0, 0, this, SLOT(slotAddSubtitle()), actionCollection(), "add_subtitle");
@@ -1408,6 +1432,7 @@ void XinePart::initActions()
 	m_position->setFocusPolicy(QWidget::NoFocus);
 	m_position->setMinimumWidth(180);
 	connect(m_position, SIGNAL(sliderMoved(int)), m_xine, SLOT(slotSeekToPosition(int)));
+	connect(m_position, SIGNAL(sliderLastMove(int)), m_xine, SLOT(slotSeekToPositionBlocking(int)));
 	connect(m_position, SIGNAL(signalStartSeeking()), m_xine, SLOT(slotStartSeeking()));
 	connect(m_position, SIGNAL(signalStopSeeking()), m_xine, SLOT(slotStopSeeking()));
 	new KWidgetAction(m_position, i18n("Position"), 0, 0, 0, actionCollection(), "player_position");
@@ -1762,7 +1787,10 @@ uint XinePart::position() const
 	if (!m_xine->isXineReady())
 		return 0;
 
-	return (int)(m_xine->getPosition() / 655.35);
+	if ( m_xine->isPlaying() )
+		return currentPosition;
+	else
+		return 0;
 }
 
 void XinePart::slotSetVolume(uint vol)
@@ -1838,8 +1866,38 @@ void XinePart::slotEnablePlayActions()
 		stateChanged("play_single_track");
 }
 
+void XinePart::slotNextAudioChannel()
+{
+	nextAudioChannel();
+}
+
+void XinePart::slotNextSubtitleChannel()
+{
+	nextSubtitleChannel();
+}
+
 /********* DCOP INTERFACE *********/
 
+void XinePart::nextAudioChannel()
+{
+	int num = m_audioChannels->items().count();
+	int index = m_audioChannels->currentItem()+1;
+	if ( index>=num )
+		index = 0;
+	m_audioChannels->setCurrentItem( index );
+	slotSetAudioChannel( index );
+}
+
+void XinePart::nextSubtitleChannel()
+{
+	int num = m_subtitles->items().count();
+	int index = m_subtitles->currentItem()+1;
+	if ( index>=num )
+		index = 0;
+	m_subtitles->setCurrentItem( index );
+	slotSetSubtitle( index );
+}
+
 int XinePart::getContrast()
 {
 	int hue, sat, contrast, bright, avOffset, spuOffset;
